import os
import tkinter as tk
from tkinter import messagebox
import sys

# Function to replace words in all text files
def replace_words():
    current_directory = os.getcwd()
    
    # Collect user inputs
    find_words = [entry.get().strip() for entry in find_entries]
    replace_words = [entry.get().strip() for entry in replace_entries]

    # Ensure the first "Find" box always runs, even if "Replace" is blank
    replacements = {}
    for i in range(len(find_words)):
        find_word = find_words[i].lower()
        replace_word = replace_words[i]

        if find_word:  # Only process if "Find" box is not empty
            replacements[find_word] = replace_word if replace_word else ""  # Replace with empty string if blank

    if not replacements:
        messagebox.showwarning("Warning", "Please enter at least one valid word to find.")
        return

    # Process all .txt files in the directory
    for filename in os.listdir(current_directory):
        if filename.endswith(".txt"):
            file_path = os.path.join(current_directory, filename)

            # Read file content
            with open(file_path, "r", encoding="utf-8") as file:
                content = file.read()

            # Perform case-insensitive replacements
            for find, replace in replacements.items():
                content = content.replace(find, replace)  # Replaces exact match
                content = content.replace(find.capitalize(), replace.capitalize())  # Capitalized match
                content = content.replace(find.upper(), replace.upper())  # Uppercase match

            # Write back the updated content
            with open(file_path, "w", encoding="utf-8") as file:
                file.write(content)

            print(f"Updated: {filename}")

    messagebox.showinfo("Success", "All files updated successfully!")

# Function to paste clipboard text into an entry box
def paste_text(entry):
    entry.delete(0, tk.END)
    entry.insert(0, root.clipboard_get())

# Function to close the application and all terminals
def exit_application():
    root.quit()
    sys.exit()  # Ensures that all terminal windows close

# Create the GUI
root = tk.Tk()
root.title("Batch Word Replacer")
root.geometry("950x450")  # Increased height to fit Exit button

# Title Label
title_label = tk.Label(root, text="Batch Word Replacer", font=("Arial", 14, "bold"))
title_label.grid(row=0, column=0, columnspan=4, pady=10)

# Labels
tk.Label(root, text="Find", font=("Arial", 12)).grid(row=1, column=1, padx=10, pady=5, sticky="w")
tk.Label(root, text="Replace With", font=("Arial", 12)).grid(row=1, column=2, padx=10, pady=5, sticky="w")

# Entry boxes and paste buttons
find_entries = []
replace_entries = []

for i in range(4):  # 4 input rows
    # Find entry & Paste button
    paste_find_btn = tk.Button(root, text="Paste", font=("Arial", 10), width=8, command=lambda e=i: paste_text(find_entries[e]))
    find_entry = tk.Entry(root, width=40, font=("Arial", 12))  # Larger input field
    
    paste_find_btn.grid(row=i+2, column=0, padx=10, pady=5)  # Paste button on the left
    find_entry.grid(row=i+2, column=1, padx=10, pady=5, sticky="w")  # Text field aligned properly
    
    # Replace entry & Paste button
    replace_entry = tk.Entry(root, width=40, font=("Arial", 12))  # Matched width
    paste_replace_btn = tk.Button(root, text="Paste", font=("Arial", 10), width=8, command=lambda e=i: paste_text(replace_entries[e]))
    
    replace_entry.grid(row=i+2, column=2, padx=10, pady=5, sticky="w")  # Text field
    paste_replace_btn.grid(row=i+2, column=3, padx=10, pady=5)  # Paste button on the right
    
    find_entries.append(find_entry)
    replace_entries.append(replace_entry)

# OK & Exit Buttons
button_frame = tk.Frame(root)
button_frame.grid(row=6, column=0, columnspan=4, pady=15)

ok_button = tk.Button(button_frame, text="OK", font=("Arial", 12, "bold"), command=replace_words, width=10)
ok_button.pack(side=tk.LEFT, padx=10)

exit_button = tk.Button(button_frame, text="Exit", font=("Arial", 12, "bold"), command=exit_application, width=10, fg="white", bg="red")
exit_button.pack(side=tk.LEFT, padx=10)

# Run the GUI
root.mainloop()
